@@ -24,7 +24,7 @@ usage2 <- function(auth_key = "your_key") {
   # DeepL API call
   response <- httr::POST(
     url = "https://api-free.deepl.com/v2/usage",
-    body = list(auth_key = auth_key)
+    httr::add_headers("Authorization" = paste("DeepL-Auth-Key", auth_key))
     )
 
   response_check(response)
